@@ -7,40 +7,26 @@ from gi.repository import Gtk, GdkPixbuf, Gdk, GObject
 from gi.repository import MatePanelApplet
 from gi.repository import Gio
 
-try:
-    import sys
-    import os
-    import commands
-    import gettext
-    import traceback
-    import time
-    import gc
-    import ctypes
-    from ctypes import *
-    import xdg.Config
-    import keybinding
-    import pointerMonitor
-except Exception, e:
-    print e
-    sys.exit( 1 )
+import sys
+import os
+import commands
+import gettext
+import traceback
+import time
+import gc
+import ctypes
+from ctypes import *
+import xdg.Config
+import keybinding
+import pointerMonitor
+import setproctitle
 
 GObject.threads_init()
 
 gdk = CDLL("libgdk-x11-2.0.so.0")
 
 # Rename the process
-architecture = commands.getoutput("uname -a")
-if (architecture.find("x86_64") >= 0):
-    libc = CDLL('libc.so.6')
-    libc.prctl(15, 'mintmenu', 0, 0, 0)
-else:
-    import dl
-    if os.path.exists('/lib/libc.so.6'):
-        libc = dl.open('/lib/libc.so.6')
-        libc.call('prctl', 15, 'mintmenu', 0, 0, 0)
-    elif os.path.exists('/lib/i386-linux-gnu/libc.so.6'):
-        libc = dl.open('/lib/i386-linux-gnu/libc.so.6')
-        libc.call('prctl', 15, 'mintmenu', 0, 0, 0)
+setproctitle.setproctitle('mintmenu')
 
 # i18n
 gettext.install("mintmenu", "/usr/share/linuxmint/locale")
@@ -60,14 +46,14 @@ from execute import *
 class MainWindow( object ):
     """This is the main class for the application"""
 
-    def __init__( self, toggleButton, settings, keybinder ):
+    def __init__( self, toggleButton, settings, keybinder, de ):
 
         self.settings = settings
         self.keybinder = keybinder
         self.path = PATH
         sys.path.append( os.path.join( self.path, "plugins") )
 
-        self.detect_desktop_environment()
+        self.de = de
 
         self.icon = "/usr/lib/linuxmint/mintMenu/visualisation-logo.png"
 
@@ -186,20 +172,6 @@ class MainWindow( object ):
             self.window.modify_bg( Gtk.StateType.NORMAL, defaultStyle.lookup_color('bg_color')[1] )
         self.border.set_padding( self.borderwidth, self.borderwidth, self.borderwidth, self.borderwidth )
 
-    def detect_desktop_environment (self):
-        self.de = "mate"
-        try:
-            de = os.environ["DESKTOP_SESSION"]
-            if de in ["gnome", "gnome-shell", "mate", "kde", "xfce"]:
-                self.de = de
-            else:
-                if os.path.exists("/usr/bin/caja"):
-                    self.de = "mate"
-                elif os.path.exists("/usr/bin/thunar"):
-                    self.de = "xfce"
-        except Exception, detail:
-            print detail
-
     def PopulatePlugins( self ):
         self.panesToColor = [ ]
         self.headingsToColor = [ ]
@@ -473,6 +445,7 @@ class MainWindow( object ):
 class MenuWin( object ):
     def __init__( self, applet, iid ):
         self.applet = applet
+        self.detect_desktop_environment()
         self.settings = Gio.Settings.new("com.linuxmint.mintmenu")
         self.keybinder = keybinding.GlobalKeyBinding()
         self.settings.connect( "changed::applet-text", self.reloadSettings )
@@ -494,7 +467,8 @@ class MenuWin( object ):
         self.applet.connect( "change-orient", self.changeOrientation )
         self.applet.connect("enter-notify-event", self.enter_notify)
         self.applet.connect("leave-notify-event", self.leave_notify)
-        self.mainwin = MainWindow( self.button_box, self.settings, self.keybinder )
+
+        self.mainwin = MainWindow( self.button_box, self.settings, self.keybinder, self.de )
         self.mainwin.window.connect( "map-event", self.onWindowMap )
         self.mainwin.window.connect( "unmap-event", self.onWindowUnmap )
         self.mainwin.window.connect( "realize", self.onRealize )
@@ -601,7 +575,7 @@ class MenuWin( object ):
 
     def loadSettings( self, *args, **kargs ):
         self.hideIcon   =  self.settings.get_boolean( "hide-applet-icon" )
-        self.buttonText =  self.settings.get_string( "applet-text" )
+        self.buttonText =  self.settings.get_string("applet-text")
         self.theme_name =  self.settings.get_string( "theme-name" )
         self.hotkeyText =  self.settings.get_string( "hot-key" )
         self.buttonIcon =  self.settings.get_string( "applet-icon" )
@@ -829,6 +803,22 @@ class MenuWin( object ):
         xml = os.path.join( os.path.join( os.path.dirname( __file__ )), "popup.xml" )
         self.applet.setup_menu_from_file(xml, action_group)
 
+    def detect_desktop_environment (self):
+        self.de = "mate"
+        try:
+            de = os.environ["XDG_CURRENT_DESKTOP"].lower()
+            if de in ["gnome", "gnome-shell", "mate", "kde", "xfce"]:
+                self.de = de
+            elif de in ['cinnamon', 'x-cinnamon']:
+            	self.de = 'cinnamon'
+            else:
+                if os.path.exists("/usr/bin/caja"):
+                    self.de = "mate"
+                elif os.path.exists("/usr/bin/thunar"):
+                    self.de = "xfce"
+        except Exception, detail:
+            print detail
+
 def applet_factory( applet, iid, data ):
     MenuWin( applet, iid )
     applet.show()
