@@ -174,6 +174,12 @@ class pluginclass( object ):
         self.toggleButton = toggleButton
         self.de = de
 
+        # Detect the locale (this is used for the Wikipedia search)
+        self.lang = "en"
+        lang = os.getenv('LANG')
+        if lang is not None and lang != "":
+            self.lang = lang.split("_")[0]
+
         self.builder = Gtk.Builder()
         # The Glade file for the plugin
         self.builder.add_from_file (os.path.join( os.path.dirname( __file__ ), "applications.glade" ))
@@ -242,9 +248,11 @@ class pluginclass( object ):
             self.settings.notifyAdd( "use-apt", self.switchAPTUsage)
             self.settings.notifyAdd( "fav-cols", self.changeFavCols )
             self.settings.notifyAdd( "remember-filter", self.changeRememberFilter)
+            self.settings.notifyAdd( "enable-internet-search", self.changeEnableInternetSearch)
 
             self.settings.bindGSettingsEntryToVar( "int", "category-hover-delay", self, "categoryhoverdelay" )
             self.settings.bindGSettingsEntryToVar( "bool", "do-not-filter", self, "donotfilterapps" )
+            self.settings.bindGSettingsEntryToVar( "bool", "enable-internet-search", self, "enableInternetSearch" )
             self.settings.bindGSettingsEntryToVar( "string", "search-command", self, "searchtool" )
             self.settings.bindGSettingsEntryToVar( "int", "default-tab", self, "defaultTab" )
         except Exception, detail:
@@ -387,6 +395,9 @@ class pluginclass( object ):
     def changeRememberFilter( self, settings, key, args):
         self.rememberFilter = settings.get_boolean(key)
 
+    def changeEnableInternetSearch( self, settings, key, args):
+        self.enableInternetSearch = settings.get_boolean(key)
+
     def changeShowApplicationComments( self, settings, key, args ):
         self.showapplicationcomments = settings.get_boolean(key)
         for child in self.applicationsBox:
@@ -451,6 +462,7 @@ class pluginclass( object ):
         self.showapplicationcomments = self.settings.get( "bool", "show-application-comments")
         self.useAPT = self.settings.get( "bool", "use-apt")
         self.rememberFilter = self.settings.get( "bool", "remember-filter")
+        self.enableInternetSearch = self.settings.get( "bool", "enable-internet-search")
 
         self.lastActiveTab =  self.settings.get( "int", "last-active-tab")
         self.defaultTab = self.settings.get( "int", "default-tab")
@@ -577,28 +589,29 @@ class pluginclass( object ):
 
         text = "<b>%s</b>" % text
 
-        suggestionButton = SuggestionButton(Gtk.STOCK_ADD, self.iconSize, "")
-        suggestionButton.connect("clicked", self.search_google)
-        suggestionButton.set_text(_("Search Google for %s") % text)
-        suggestionButton.set_image("/usr/lib/linuxmint/mintMenu/search_engines/google.ico")
-        self.applicationsBox.add(suggestionButton)
-        self.suggestions.append(suggestionButton)
+        if self.enableInternetSearch:
+            suggestionButton = SuggestionButton(Gtk.STOCK_ADD, self.iconSize, "")
+            suggestionButton.connect("clicked", self.search_ddg)
+            suggestionButton.set_text(_("Search DuckDuckGo for %s") % text)
+            suggestionButton.set_image("/usr/lib/linuxmint/mintMenu/search_engines/ddg.png")
+            self.applicationsBox.add(suggestionButton)
+            self.suggestions.append(suggestionButton)
 
-        suggestionButton = SuggestionButton(Gtk.STOCK_ADD, self.iconSize, "")
-        suggestionButton.connect("clicked", self.search_wikipedia)
-        suggestionButton.set_text(_("Search Wikipedia for %s") % text)
-        suggestionButton.set_image("/usr/lib/linuxmint/mintMenu/search_engines/wikipedia.ico")
-        self.applicationsBox.add(suggestionButton)
-        self.suggestions.append(suggestionButton)
+            suggestionButton = SuggestionButton(Gtk.STOCK_ADD, self.iconSize, "")
+            suggestionButton.connect("clicked", self.search_wikipedia)
+            suggestionButton.set_text(_("Search Wikipedia for %s") % text)
+            suggestionButton.set_image("/usr/lib/linuxmint/mintMenu/search_engines/wikipedia.ico")
+            self.applicationsBox.add(suggestionButton)
+            self.suggestions.append(suggestionButton)
 
-        separator = Gtk.EventBox()
-        separator.add(Gtk.HSeparator())
-        separator.set_visible_window(False)
-        separator.set_size_request(-1, 20)
-        separator.type = "separator"
-        separator.show_all()
-        self.applicationsBox.add(separator)
-        self.suggestions.append(separator)
+            separator = Gtk.EventBox()
+            separator.add(Gtk.HSeparator())
+            separator.set_visible_window(False)
+            separator.set_size_request(-1, 20)
+            separator.type = "separator"
+            separator.show_all()
+            self.applicationsBox.add(separator)
+            self.suggestions.append(separator)
 
         suggestionButton = SuggestionButton(Gtk.STOCK_ADD, self.iconSize, "")
         suggestionButton.connect("clicked", self.search_dictionary)
@@ -1007,22 +1020,24 @@ class pluginclass( object ):
     def searchPopup( self, widget=None, event=None ):
         menu = Gtk.Menu()
 
-        menuItem = Gtk.ImageMenuItem(_("Search Google"))
-        img = Gtk.Image()
-        img.set_from_file('/usr/lib/linuxmint/mintMenu/search_engines/google.ico')
-        menuItem.set_image(img)
-        menuItem.connect("activate", self.search_google)
-        menu.append(menuItem)
+        if self.enableInternetSearch:
 
-        menuItem = Gtk.ImageMenuItem(_("Search Wikipedia"))
-        img = Gtk.Image()
-        img.set_from_file('/usr/lib/linuxmint/mintMenu/search_engines/wikipedia.ico')
-        menuItem.set_image(img)
-        menuItem.connect("activate", self.search_wikipedia)
-        menu.append(menuItem)
+            menuItem = Gtk.ImageMenuItem(_("Search DuckDuckGo"))
+            img = Gtk.Image()
+            img.set_from_file('/usr/lib/linuxmint/mintMenu/search_engines/ddg.png')
+            menuItem.set_image(img)
+            menuItem.connect("activate", self.search_ddg)
+            menu.append(menuItem)
 
-        menuItem = Gtk.SeparatorMenuItem()
-        menu.append(menuItem)
+            menuItem = Gtk.ImageMenuItem(_("Search Wikipedia"))
+            img = Gtk.Image()
+            img.set_from_file('/usr/lib/linuxmint/mintMenu/search_engines/wikipedia.ico')
+            menuItem.set_image(img)
+            menuItem.connect("activate", self.search_wikipedia)
+            menu.append(menuItem)
+
+            menuItem = Gtk.SeparatorMenuItem()
+            menu.append(menuItem)
 
         menuItem = Gtk.ImageMenuItem(_("Lookup Dictionary"))
         img = Gtk.Image()
@@ -1095,16 +1110,16 @@ class pluginclass( object ):
         y = rect.y + rect.height
         return (x, y, False)
 
-    def search_google(self, widget):
+    def search_ddg(self, widget):
         text = self.searchEntry.get_text()
         text = text.replace(" ", "+")
-        os.system("xdg-open \"http://www.google.com/cse?cx=002683415331144861350%3Atsq8didf9x0&ie=utf-8&sa=Search&q=" + text + "\" &")
+        os.system("xdg-open \"https://duckduckgo.com/?q=%s&t=lm&ia=web\" &" % text)
         self.mintMenuWin.hide()
 
     def search_wikipedia(self, widget):
         text = self.searchEntry.get_text()
         text = text.replace(" ", "+")
-        os.system("xdg-open \"http://en.wikipedia.org/wiki/Special:Search?search=" + text + "\" &")
+        os.system("xdg-open \"http://%s.wikipedia.org/wiki/Special:Search?search=%s\" &" % (self.lang, text))
         self.mintMenuWin.hide()
 
     def search_dictionary(self, widget):
